/**
 * IBM Confidential
 *
 * OCO Source Materials
 *
 * XML Cursor Interface for Java (XCI-J)
 *
 * © Copyright IBM Corp. 2012
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 */
/**
 * @author keshlam
 *
 */
package org.apache.xml.utils;

import java.util.Random;


/* NO JAVADOC
   RTC Defect 28534 covers the risk of DOS attack through hash aliasing.
   Oracle has accepted the need to fix that when hashing Strings, but has
   not addressed it for other classes. We have a number of String-like
   hash keys  which are relatively exposed to such an attack; to protect
   them, we have implmeneted this hash function, which performs a simple
   shufle-substitution encyphering while calculating the hash value, randomly
   initialized each time the program is started. This should be sufficient
   to prevent abuse without having unduly large overhead.
*/
final public class PerSessionHash
{
	/** IBM binary license notice. */
	final static String IBM_COPYRIGHT = "Licensed Materials - Property of IBM\n\n"
			+ "XML Cursor Interface for Java (XCI-J)" + "© Copyright IBM Corp. 2012. All Rights Reserved.\n\n"
			+ "US Government Users Restricted Rights - Use, duplication or disclosure \n"
			+ "restricted by GSA ADP Schedule Contract with IBM Corp.";

	protected static void shuffle(Random r, int[] s)
	{
		final int l = s.length;
		for(int i = l - 1; i >= 0; --i)
		{
			int j = r.nextInt(l);
			int t = s[i];
			s[i] = s[j];
			s[j] = t;
		} 
	}

	// Safe hash support: Substitution table, local hash and cache. 
	// High and low byte have separate hashtables,for no especially good reason
	protected static int[] _substitute8, _substitute;
	static
	{
		Random r = new Random(); 
		_substitute = new int[256];
		for(int i = 255; i >= 0; --i)   // Start with identity map
			_substitute[i] = i;
		shuffle(r, _substitute);   // Simple shuffle to produce a substitution cipher

		_substitute8 = new int[256];
		for(int i = 255; i >= 0; --i)   // Start with identity map
			_substitute8[i] = i;
		shuffle(r, _substitute8);   // Simple shuffle to produce a substitution cipher
	}

	/**
	 * @see javax.xml.namespaces.QName.hashCode()
	 */
	public static int hash(String s)
	{
		int h = 0; // Or _shuffle[0]?

		// A common hash function, but with input substituted
		for(int i = s.length() - 1; i >= 0; --i)
		{
			char c = s.charAt(i);
			h = (h << 5) + h + _substitute8[c >> 8];
			h = (h << 5) + h + _substitute[c & 255];
		}

		return h;
	}    
}
